@@ -483,18 +483,18 @@ re_send:
 	memcpy(ob + 8 + 32, work->data + 64, 12);
 	if (!bitforce->nonce_range) {
 		sprintf((char *)ob + 8 + 32 + 12, ">>>>>>>>");
-		work->blk.nonce = bitforce->nonces = 0xffffffff;
+		work->nonce = bitforce->nonces = 0xffffffff;
 		len = 60;
 	} else {
 		uint32_t *nonce;
 
 		nonce = (uint32_t *)(ob + 8 + 32 + 12);
-		*nonce = htobe32(work->blk.nonce);
+		*nonce = htobe32(work->nonce);
 		nonce = (uint32_t *)(ob + 8 + 32 + 12 + 4);
 		/* Split work up into 1/5th nonce ranges */
 		bitforce->nonces = 0x33333332;
-		*nonce = htobe32(work->blk.nonce + bitforce->nonces);
-		work->blk.nonce += bitforce->nonces + 1;
+		*nonce = htobe32(work->nonce + bitforce->nonces);
+		work->nonce += bitforce->nonces + 1;
 		sprintf((char *)ob + 8 + 32 + 12 + 8, ">>>>>>>>");
 		len = 68;
 	}
@@ -634,12 +634,12 @@ static int64_t bitforce_get_result(struct thr_info *thr, struct work *work)
 #ifndef __BIG_ENDIAN__
 		nonce = swab32(nonce);
 #endif
-		if (unlikely(bitforce->nonce_range && (nonce >= work->blk.nonce ||
-			(work->blk.nonce > 0 && nonce < work->blk.nonce - bitforce->nonces - 1)))) {
+		if (unlikely(bitforce->nonce_range && (nonce >= work->nonce ||
+			(work->nonce > 0 && nonce < work->nonce - bitforce->nonces - 1)))) {
 				applog(LOG_WARNING, "%s%i: Disabling broken nonce range support",
 					bitforce->drv->name, bitforce->device_id);
 				bitforce->nonce_range = false;
-				work->blk.nonce = 0xffffffff;
+				work->nonce = 0xffffffff;
 				bitforce->sleep_ms *= 5;
 				bitforce->kname = KNAME_WORK;
 		}
