@@ -134,24 +134,25 @@ struct usb_intinfo {
 
 enum sub_ident {
 	IDENT_UNK = 0,
+	IDENT_AMU,
+	IDENT_AVA,
 	IDENT_BAJ,
 	IDENT_BAL,
-	IDENT_BAS,
 	IDENT_BAM,
-	IDENT_BFL,
-	IDENT_BFU,
-	IDENT_MMQ,
-	IDENT_AVA,
-	IDENT_BTB,
-	IDENT_HFA,
+	IDENT_BAS,
 	IDENT_BBF,
-	IDENT_KLN,
-	IDENT_ICA,
-	IDENT_AMU,
+	IDENT_BF1,
+	IDENT_BFL,
 	IDENT_BLT,
-	IDENT_LLT,
+	IDENT_BTB,
+	IDENT_BXF,
 	IDENT_CMR1,
 	IDENT_CMR2,
+	IDENT_HFA,
+	IDENT_ICA,
+	IDENT_KLN,
+	IDENT_LLT,
+	IDENT_MMQ,
 	IDENT_ZTX
 };
 
@@ -342,6 +343,12 @@ struct cg_usb_info {
 	USB_ADD_COMMAND(C_BF1_FLUSH, "BF1Flush") \
 	USB_ADD_COMMAND(C_BF1_IFLUSH, "BF1InterruptFlush") \
 	USB_ADD_COMMAND(C_BF1_IDENTIFY, "BF1Identify") \
+	USB_ADD_COMMAND(C_BXF_READ, "BXFRead") \
+	USB_ADD_COMMAND(C_BXF_WORK, "BXFWork") \
+	USB_ADD_COMMAND(C_BXF_TARGET, "BXFTarget") \
+	USB_ADD_COMMAND(C_BXF_VERSION, "BXFVersion") \
+	USB_ADD_COMMAND(C_BXF_MAXROLL, "BXFMaxRoll") \
+	USB_ADD_COMMAND(C_BXF_FLUSH, "BXFFlush") \
 	USB_ADD_COMMAND(C_HF_RESET, "HFReset") \
 	USB_ADD_COMMAND(C_HF_PLL_CONFIG, "HFPLLConfig") \
 	USB_ADD_COMMAND(C_HF_ADDRESS, "HFAddress") \
